@@ -22,31 +22,19 @@ def cigar_splitter(cigar):
     return cigar_splitted
 
 
-'''
-    # aligned_len: M I X =
-    # clipping_len: S
-    # mismatch_len: X I D
-    # mismatch_pct = mismatch_len / aligned_len
-    # aligned_pct  = aligned_len  / (aligned_len + clipping_len)
-    # clipping_pct = clipping_len / (aligned_len + clipping_len)
-
-22=2X65=
-22=1X1D65=
-22=1X1I65=
-22=2D65=
-
-    for each_part in cigar_splitted:
-        each_part_len = int(each_part[:-1])
-        each_part_cate = each_part[-1]
-
-'''
-
-
-cigar_splitted = cigar_splitter('6S8=1D8=2X65S')
-
-
 def continuous_mismatch_cigar(cigar_splitted):
 
+    print(cigar_splitted)
+
+    if cigar_splitted[0][-1] in ['S', 's']:
+        cigar_splitted = cigar_splitted[1:]
+
+    if cigar_splitted[-1][-1] in ['S', 's']:
+        cigar_splitted = cigar_splitted[:-1]
+
+    print(cigar_splitted)
+
+
     mismatch_len_list = []
     mismatch_len = 0
     for each_part in cigar_splitted:
@@ -60,19 +48,24 @@ def continuous_mismatch_cigar(cigar_splitted):
             if each_part_cate not in ['=', 'S']:
                 mismatch_len += each_part_len
 
+    print(mismatch_len_list)
+
     continuous_mismatch = False
     if max(mismatch_len_list) > 1:
         continuous_mismatch = True
 
-    print(cigar_splitted)
-    print(mismatch_len_list)
-    print(continuous_mismatch)
-
+    print(max(mismatch_len_list))
     return continuous_mismatch
 
 
+'''
+22=2X65=
+22=1X1D65=
+22=1X1I65=
+22=2D65=
+'''
 
+cigar = '6S8=1D2=1X65S'
 
-continuous_mismatch_cigar(cigar_splitted)
-
+print(continuous_mismatch_cigar(cigar_splitter(cigar)))
 
