@@ -98,9 +98,9 @@ mlen = '45'
 
 #MarkerMAG_linkages          = '/Users/songweizhi/Desktop/tunning_rd2_up/stats_GapFilling_gnm_filtered.txt'
 linkages_from_rd1           = False
-
-MarkerMAG_linkages          = '/Users/songweizhi/Desktop/tunning_rd1_GI/stats_combined_filtered.txt'
-linkages_from_rd1           = True
+#
+# MarkerMAG_linkages          = '/Users/songweizhi/Desktop/tunning_rd1_GI/stats_combined_filtered.txt'
+# linkages_from_rd1           = True
 
 '''
 GI_0719_128_45_45_1200_linkages_by_genome.txt	Rd_1	|	59	59	0	0	59/59(100.0)	|	19	19	0	0	0	19/97(19.59)	19/19(100.0)
