@@ -32,10 +32,36 @@ gtdb_gnm_to_ssu_txt = '%s/GTDB_ssu_all_r95_gnm_to_ssu.txt'
 # Kelp_0406_specific_identified_linkages_genome_level.txt
 # Kelp_0406_very_specific_identified_linkages_genome_level.txt
 # Kelp_0406_super_specific_identified_linkages_genome_level.txt
-linkage_file = '/Users/songweizhi/Desktop/new_algorithm_Kelp/Kelp_0602_60_60_linkages_by_genome.txt'
+linkage_file = '/Users/songweizhi/Desktop/assess_linkages_Kelp/Kelp_0721_60_60_900_linkages_by_genome.txt'
 
 
 '''
+
+=============================
+Linkage accuracy: Kelp_0721_60_60_900_linkages_by_genome
+Rank	All	NA	Correct	Unknown	Total(Accuracy)
+phylum	38	0	38	0	38/38(100.0)
+class	38	0	36	0	36/38(94.74)
+order	38	0	34	0	34/38(89.47)
+family	38	0	32	0	32/38(84.21)
+genus	38	0	19	8	27/38(71.05)
+=============================
+linked MAGs: 24
+
+
+=============================
+Linkage accuracy: Kelp_0721_45_45_900_linkages_by_genome
+Rank	All	NA	Correct	Unknown	Total(Accuracy)
+phylum	38	0	38	0	38/38(100.0)
+class	38	0	36	0	36/38(94.74)
+order	38	0	34	0	34/38(89.47)
+family	38	0	32	0	32/38(84.21)
+genus	38	0	20	7	27/38(71.05)
+=============================
+linked MAGs: 22
+
+
+
 Linkage accuracy: Kelp_0602_60_60_linkages_by_genome
 Rank	All	NA	Correct	Unknown	Total(Accuracy)
 phylum	59	1	58	0	58/58(100.0)
